[**简体中文**](https://github.com/zhangxp93/PyInst/blob/main/README.md) | [**English**](https://github.com/zhangxp93/PyInst/blob/main/README_en.md)

<div align="center">
 <h1>
 <strong>PyVISA仪器控制</strong>
 </h1>
<h5>
  <strong>适用于 Windows、MacOs、Linux</strong><br>
</h5>
</div><br>

___

- **基于pyvisa库对仪器进行控制，支持USB、GPIB、TCP/IP等连接方式。**
- **Rohde & Schwarz SCPI**
- **KeySight SCPI**


## 必要依赖库安装
PyVISA 是一个用于控制和通信仪器的 Python 库,使用下面的代码安装:

```
pip install pyvisa
```



## 🏷[更新日志](https://github.com/zhangxp93/PyInst/blob/main/CHANGELOG.md)

